@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -110,7 +110,7 @@ sub configure {
         : (),
 
     ($distmeta->{x_authority} // '') eq 'cpan:DROLSKY'
-    ? q{I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.}
+    ? q{I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.}
     : (),
 ) }}
 SUPPORT
@@ -251,7 +251,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.76
+version 0.77
 
 =head1 SYNOPSIS
 
@@ -432,7 +432,7 @@ L<Dist::Zilla::PluginBundle::DROLSKY>
 Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DROLSKY>
 (or L<bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org|mailto:bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org>).
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
 =head1 AUTHOR
 
